Experiment
===========

.. automodule:: cornac.experiment

Experiment
--------------------------------------------
.. automodule:: cornac.experiment.experiment
   :members:

Result
----------------------------------------
.. automodule:: cornac.experiment.result
   :members: Result

CVResult
----------------------------------------
.. automodule:: cornac.experiment.result
   :members: CVResult

ExperimentResult
----------------------------------------
.. automodule:: cornac.experiment.result
   :members: ExperimentResult

CVExperimentResult
----------------------------------------
.. automodule:: cornac.experiment.result
   :members: CVExperimentResult